@@ -155,6 +155,12 @@ class Parser:
             elif type(tok) is defs.AccentToken:
                 out += self.expand_accent(buf, tok)
                 continue
+            elif tok.txt == '\\\\':
+                out.append(defs.ActionToken(tok.pos))
+                out.append(defs.SpaceToken(tok.pos, ' '))
+                buf.next()
+                self.parse_newline_option(buf, True)
+                continue
             elif tok.txt == '{' or tok.txt == '}':
                 out.append(defs.ActionToken(tok.pos))
             elif type(tok) is defs.SpecialToken:
@@ -196,6 +202,7 @@ class Parser:
             return scanner.Buffer([tok])
         pos = tok.pos
         lev = 1 if tok.txt == '{' else 0
+        opening_tok = tok
         tok = buf.next()    # skip opening { or [
         out = []
         while tok:
@@ -210,8 +217,19 @@ class Parser:
                 return scanner.Buffer(out)
             out.append(tok)
             tok = buf.next()
-        return scanner.Buffer(utils.latex_error('cannot find closing ' + end,
-                                            pos, self.latex, self.parms) + out)
+
+        # HACK, see Issue 23:
+        # We have read till end of text, and the collected tokens might be
+        # skipped by the caller.
+        # Thus, we push back the tokens to the input, together with an
+        # error message.
+        # To the caller, we return a buffer only yielding an error mark.
+        buf.back([opening_tok]
+                    + utils.latex_error('cannot find closing "' + end + '"',
+                                        pos, self.latex, self.parms) + out)
+        return scanner.Buffer([defs.TextToken(opening_tok.pos,
+                                    ' ' + self.parms.mark_latex_error + ' ',
+                                    pos_fix=True)])
 
     #   expand a "normal" macro
     #   Return: tokens to be inserted
@@ -365,6 +383,18 @@ class Parser:
         buf.next()
         return self.get_text_expanded(self.arg_buffer(buf, tok.pos).all())
 
+    #   parse (skip) optional [...] after \\
+    #
+    def parse_newline_option(self, buf, skip_space):
+        if skip_space:
+            # we do not want to remove a line break for \\ without [...]
+            tok = buf.look_ahead()
+            if tok and tok.txt == '[':
+                buf.skip_space()
+        tok = buf.cur()
+        if tok and tok.txt == '[':
+            self.arg_buffer(buf, tok.pos, end=']')
+
     #   generate string from token sequence, without macro expansion
     #
     def get_text_direct(self, toks):
